@@ -45,7 +45,7 @@ except ImportError:
     from wagtail.wagtailsnippets.views.snippets import SNIPPET_EDIT_HANDLERS
 from wagtail_modeltranslation.settings import CUSTOM_SIMPLE_PANELS, CUSTOM_COMPOSED_PANELS, TRANSLATE_SLUGS
 from wagtail_modeltranslation.utils import compare_class_tree_depth
-from wagtail_modeltranslation.patch_wagtailadmin_forms import WagtailFixedAdminPageForm
+from wagtail_modeltranslation.patch_wagtailadmin_forms import patch_admin_page_form
 from wagtail import VERSION
 
 logger = logging.getLogger('wagtail.core')
@@ -102,7 +102,7 @@ class WagtailTranslator(object):
 
         for field in model.search_fields:
             # Check if the field is a SearchField and if it is one of the fields registered for translation
-            if field.__class__ is SearchField and field.field_name in translation_registered_fields:
+            if isinstance(field, SearchField) and field.field_name in translation_registered_fields:
                 # If it is we create a clone of the original SearchField to keep all the defined options
                 # and replace its name by the translated one
                 for language in mt_settings.AVAILABLE_LANGUAGES:
@@ -118,7 +118,7 @@ class WagtailTranslator(object):
                 _patch_stream_field_meaningful_value(descriptor)
 
         # OVERRIDE CLEAN METHOD
-        model.base_form_class = WagtailFixedAdminPageForm
+        model.base_form_class = patch_admin_page_form(model.base_form_class)
 
         # OVERRIDE PAGE METHODS
         if TRANSLATE_SLUGS:
